==> huaweicloudsdkcoc-3.1.140-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_personnel_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPersonnelResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'personnel': 'list[PersonnelResponse]',
        'count': 'int'
    }

    attribute_map = {
        'personnel': 'personnel',
        'count': 'count'
    }

    def __init__(self, personnel=None, count=None):
        """ListPersonnelResponse

        The model defined in huaweicloud sdk

        :param personnel: 人员信息
        :type personnel: list[:class:`huaweicloudsdkcoc.v1.PersonnelResponse`]
        :param count: 总数
        :type count: int
        """
        
        super(ListPersonnelResponse, self).__init__()

        self._personnel = None
        self._count = None
        self.discriminator = None

        if personnel is not None:
            self.personnel = personnel
        if count is not None:
            self.count = count

    @property
    def personnel(self):
        """Gets the personnel of this ListPersonnelResponse.

        人员信息

        :return: The personnel of this ListPersonnelResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.PersonnelResponse`]
        """
        return self._personnel

    @personnel.setter
    def personnel(self, personnel):
        """Sets the personnel of this ListPersonnelResponse.

        人员信息

        :param personnel: The personnel of this ListPersonnelResponse.
        :type personnel: list[:class:`huaweicloudsdkcoc.v1.PersonnelResponse`]
        """
        self._personnel = personnel

    @property
    def count(self):
        """Gets the count of this ListPersonnelResponse.

        总数

        :return: The count of this ListPersonnelResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListPersonnelResponse.

        总数

        :param count: The count of this ListPersonnelResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPersonnelResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.148-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_personnel_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPersonnelResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'personnel': 'list[PersonnelResponse]',
        'count': 'int'
    }

    attribute_map = {
        'personnel': 'personnel',
        'count': 'count'
    }

    def __init__(self, personnel=None, count=None):
        r"""ListPersonnelResponse

        The model defined in huaweicloud sdk

        :param personnel: 人员信息
        :type personnel: list[:class:`huaweicloudsdkcoc.v1.PersonnelResponse`]
        :param count: 总数
        :type count: int
        """
        
        super(ListPersonnelResponse, self).__init__()

        self._personnel = None
        self._count = None
        self.discriminator = None

        if personnel is not None:
            self.personnel = personnel
        if count is not None:
            self.count = count

    @property
    def personnel(self):
        r"""Gets the personnel of this ListPersonnelResponse.

        人员信息

        :return: The personnel of this ListPersonnelResponse.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.PersonnelResponse`]
        """
        return self._personnel

    @personnel.setter
    def personnel(self, personnel):
        r"""Sets the personnel of this ListPersonnelResponse.

        人员信息

        :param personnel: The personnel of this ListPersonnelResponse.
        :type personnel: list[:class:`huaweicloudsdkcoc.v1.PersonnelResponse`]
        """
        self._personnel = personnel

    @property
    def count(self):
        r"""Gets the count of this ListPersonnelResponse.

        总数

        :return: The count of this ListPersonnelResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListPersonnelResponse.

        总数

        :param count: The count of this ListPersonnelResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPersonnelResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
